"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ensureGitRepo = void 0;
const fs_1 = __importDefault(require("fs"));
const isomorphic_git_1 = require("isomorphic-git");
const ensureGitRepo = (config, origin, mainBranch) => __awaiter(void 0, void 0, void 0, function* () {
    const repoExists = yield (0, isomorphic_git_1.currentBranch)({ fs: fs_1.default, dir: config.targetDir }).catch(() => undefined);
    if (repoExists) {
        if (config.gitRepo) {
            throw new Error("For now you cannot manage an existing git repo");
        }
        if (config.gitCommits) {
            yield checkExistingRepo(config, origin, mainBranch);
            return;
        }
        return;
    }
    if (config.gitRepo) {
        if (!origin) {
            throw new Error("You need to specify an origin for the new git repo");
        }
        yield createNewRepo(config, origin, mainBranch);
        return;
    }
    if (config.gitCommits) {
        throw new Error("You need to be in or generate a git repo if you want to create git commits");
    }
});
exports.ensureGitRepo = ensureGitRepo;
const checkExistingRepo = (config, origin, mainBranch) => __awaiter(void 0, void 0, void 0, function* () {
    const actualBranch = yield (0, isomorphic_git_1.currentBranch)({ fs: fs_1.default, dir: config.targetDir });
    if (actualBranch !== mainBranch) {
        throw new Error(`Current branch is ${actualBranch}, but should be ${mainBranch}`);
    }
    const remotes = yield (0, isomorphic_git_1.listRemotes)({ fs: fs_1.default, dir: "." });
    if (remotes.length === 0) {
        if (!origin) {
            throw new Error("You need to specify an origin for the new git repo");
        }
        yield (0, isomorphic_git_1.addRemote)({ fs: fs_1.default, dir: config.targetDir, remote: "origin", url: origin });
        return;
    }
    const originRemote = remotes.find(remote => remote.remote === "origin");
    if (!originRemote) {
        throw new Error("Your git remote needs to be called origin for now. Open an issue if you need this to be configurable.");
    }
    if (originRemote.url !== origin) {
        throw new Error(`The remote of the existing git repo is different to the new one. Existing: ${originRemote.url}, New: ${origin}`);
    }
    return;
});
const createNewRepo = (config, origin, mainBranch) => __awaiter(void 0, void 0, void 0, function* () {
    config.logger.logState("gitcreate", { state: "active", text: "Initializing git repo" });
    yield (0, isomorphic_git_1.init)({ fs: fs_1.default, dir: config.targetDir, defaultBranch: mainBranch });
    config.logger.logState("gitcreate", { state: "active", text: "Adding git origin" });
    yield (0, isomorphic_git_1.addRemote)({ fs: fs_1.default, dir: config.targetDir, remote: "origin", url: origin });
    config.logger.logState("gitcreate", { state: "completed", text: "Initialized git repo" });
});
