"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addVscodeSettings = void 0;
const commitWithAuthor_1 = require("../helpers/commitWithAuthor");
const withStateLogger_1 = require("../helpers/withStateLogger");
const writeAndAddFile_1 = require("../helpers/writeAndAddFile");
exports.addVscodeSettings = (0, withStateLogger_1.withStateLogger)({
    id: "vscodesettings",
    message: "Adding vscode extension and setting recommendations",
    completed: "Added vscode recommendations",
}, (config) => __awaiter(void 0, void 0, void 0, function* () {
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, ".vscode/settings.json", JSON.stringify(generateVscodeSettings(), null, 2));
    yield (0, writeAndAddFile_1.writeAndAddFile)(config, ".vscode/extensions.json", JSON.stringify(generateVscodeExtensions(), null, 2));
    yield (0, commitWithAuthor_1.commitWithAuthor)(config, "Add vscode settings");
}));
const generateVscodeSettings = () => {
    return {
        "editor.defaultFormatter": "esbenp.prettier-vscode",
        "[typescriptreact]": {
            "editor.defaultFormatter": "esbenp.prettier-vscode",
        },
        "[typescript]": {
            "editor.defaultFormatter": "esbenp.prettier-vscode",
        },
        "[javascriptreact]": {
            "editor.defaultFormatter": "esbenp.prettier-vscode",
        },
        "[javascript]": {
            "editor.defaultFormatter": "esbenp.prettier-vscode",
        },
        "[jsonc]": {
            "editor.defaultFormatter": "esbenp.prettier-vscode",
        },
        "[json]": {
            "editor.defaultFormatter": "esbenp.prettier-vscode",
        },
        "editor.formatOnSave": true,
        "editor.codeActionsOnSave": {
            "source.fixAll.eslint": true,
        },
        "gitlens.hovers.currentLine.over": "line",
        "editor.tabCompletion": "on",
        "editor.inlineSuggest.enabled": true,
        "typescript.updateImportsOnFileMove.enabled": "always",
        "eslint.packageManager": "yarn",
        "editor.quickSuggestions": {
            strings: true,
        },
        "typescript.preferences.importModuleSpecifier": "non-relative",
    };
};
const generateVscodeExtensions = () => {
    return {
        recommendations: [
            "dbaeumer.vscode-eslint",
            "eamodio.gitlens",
            "wix.vscode-import-cost",
            "orta.vscode-jest",
            "esbenp.prettier-vscode",
        ],
    };
};
